@@ -6,7 +6,7 @@ import socketio
 from aiortc import MediaStreamTrack, RTCPeerConnection
 from aiortc.rtcrtpreceiver import RemoteStreamTrack
 
-from pitrack import PiH264Relay
+from gspeerconnection.pitrack import PiH264Relay
 
 
 class GSPeerConnectionWatcher:
